import QtQuick 1.1
import com.nokia.meego 1.0
import SqliteAccess 1.0


Page {
    id: myTopSites
    tools: commonTools

    property bool retVal : false
    property bool newFlag : false

    property color fillColFont : mySqlDb.fontColor
    property color fillColBack : mySqlDb.backgroundColor

    property AccessDb mySqlDb
    width: 480
    height: 854


    ColorChooser {
        id: myColorChooser
    }

    Label {
        id: lApp
        anchors.horizontalCenter: parent.horizontalCenter
        y: 15
        text: qsTr("My Top Sites")
        font.pixelSize: 32
    }

    Button {
        id: bBckw
        x: 15
        y: lApp.y - 2
        width: 75
        height: 45
        text: qsTr("<")
        onClicked:
        {
            retVal = mySqlDb.readRecordBwd
            tUrl.text = mySqlDb.coreUrl
            tTitle.text = mySqlDb.title
            fillColFont = mySqlDb.fontColor
            fillColBack = mySqlDb.backgroundColor
            tAccessCount.text = mySqlDb.accessCount
            newFlag = false
        }
    }

    Button {
        id: bFwd
        x: 390
        y: bBckw.y
        width: bBckw.width
        height: bBckw.height
        text: qsTr(">")
        onClicked:
        {
            retVal = mySqlDb.readRecordFwd
            tUrl.text = mySqlDb.coreUrl
            tTitle.text = mySqlDb.title
            fillColFont = mySqlDb.fontColor
            fillColBack = mySqlDb.backgroundColor
            tAccessCount.text = mySqlDb.accessCount
            newFlag = false
        }
    }

    Label {
        id: lUrl
        x: 13
        y:  bBckw.y + lApp.height + 12
        text: qsTr("Url")
        font.pixelSize: 25
        font.bold: true
        color: "red"
    }

    TextArea {
        id: tUrl
        anchors.horizontalCenter: parent.horizontalCenter
        y: lUrl.y + lUrl.height - 1
        height: 100
        width: 460
        text : mySqlDb.coreUrl
        clip: true

        onTextChanged:
            tUrl.errorHighlight = false
    }

    Label {
        id: lTitle
        x: lUrl.x
        y: tUrl.y + tUrl.height + 32
        text: qsTr("Title")
        font.pixelSize: 22
        font.bold: true
        color: "red"
    }

    TextArea {
        id: tTitle
        anchors.horizontalCenter: parent.horizontalCenter
        y: lTitle.y + lTitle.height - 1
        height: 100
        width: tUrl.width
        text: mySqlDb.title
        clip: true
        wrapMode: TextEdit.Wrap
    }

    ColorButton {
        id: bFont
        x: 100
        y: lTitle.y - 20
        width: 170
        height: 45
        text: qsTr("Font Col")
        color : fillColBack
        fontCol: fillColFont
        onClicked: {
            //console.log("bFont clicked");
            myColorChooser.switchType = false
            myColorChooser.open()
        }
    }

    ColorButton {
        id: bBckgnd
        x: 295
        y: bFont.y
        width: bFont.width
        height: bFont.height
        text: qsTr("Backgrnd")
        color : fillColBack
        fontCol: fillColFont
        onClicked: {
            //console.log("bBckgnd clicked");
            myColorChooser.switchType = true
            myColorChooser.open()
        }
    }

    Label {
        id: lAccessCount
        x: 20
        y: tTitle.y + tTitle.height + 22
        text: qsTr("Access Count - Position")
        font.pixelSize: 25
        font.bold: true
        color: "red"
    }

    TextField {
        id: tAccessCount
        x: 355
        y: lAccessCount.y - 10
        width: 110
        height: 45
        text: mySqlDb.accessCount
        inputMethodHints: Qt.ImhFormattedNumbersOnly
        inputMask: "9999"
    }

    Text {
        id: tInfo
        y: lAccessCount.y + 70
        width: tUrl.width
        height: 150
        horizontalAlignment: Text.AlignHCenter
        text: qsTr("Note: Please close all MeeGo Browser\n"
                 + "windows when using MyTopSites.\n"
                 + "MyTopSites closes the browser\n"
                 + "when saving changes to prevent\n"
                 + "a possible mess with the top sites\n"
                 + "database due to concurrent access.\n" )
        color: "Blue"
        font.pixelSize: 24
    }


    InfoDialog {
        id: errorDialog
        infoTitle: qsTr("   Error")
        infoImage: "image://theme/icon-l-error"
        infoText: qsTr("\n\nDuplicate Url - it must be unique.")
        infoHeight: 3*30
    }

    Notification {
        id: saveNtf
        nText: qsTr("Site saved...")
    }

    function saveRecord(){
        mySqlDb.coreUrl = tUrl.text
        mySqlDb.title = tTitle.text
        mySqlDb.fontColor = fillColFont
        mySqlDb.backgroundColor = fillColBack
        mySqlDb.accessCount = tAccessCount.text

        if (newFlag) {
            if (!mySqlDb.newRecord) {
                errorDialog.open()

                tUrl.errorHighlight = true
            } else {
                newFlag = false
                saveNtf.show()
            }
        }
        else {
            if (!mySqlDb.writeRecord) {
                errorDialog.open()

                tUrl.errorHighlight = true
            } else {
                saveNtf.show()
            }
        }
    }

    function addRecord(){
        tUrl.text = qsTr("")
        tTitle.text = qsTr("")
        fillColFont = "Black"
        fillColBack = "White"
        tAccessCount.text = 1

        newFlag = true
    }

    QueryDialog {
            id: queryDialog
           icon: "image://theme/icon-l-browser"
            titleText: "Delete this Site?"
            message: "Press Yes or No button"
            acceptButtonText: "Yes"
            rejectButtonText: "No"
            onAccepted: {
                //console.log("YES clicked...")
                retVal = mySqlDb.delRecord

                tUrl.text = mySqlDb.coreUrl
                tTitle.text = mySqlDb.title
                fillColFont = mySqlDb.fontColor
                fillColBack = mySqlDb.backgroundColor
                tAccessCount.text = mySqlDb.accessCount
            }
            onRejected: {
                //console.log("NO clicked...");
            }
    }

    function delRecord(){
        queryDialog.message = tTitle.text
        queryDialog.open()
        newFlag = false
    }
}
